# Weaviate Agents Python Client

[![Main Branch](https://github.com/weaviate/weaviate-agents-python-client/actions/workflows/tests.yml/badge.svg?branch=main)](https://github.com/weaviate/weaviate-agents-python-client/actions)
[![PyPI version](https://badge.fury.io/py/weaviate-agents.svg)](https://badge.fury.io/py/weaviate-agents)

> ⚠️ **Alpha Release**: Weaviate Agents is currently in alpha and is subject to change. Features may be modified or removed without notice. Please check that you are using the latest version of the package.

This package is a sub-package to be used in conjunction with the [Weaviate Python Client](https://github.com/weaviate/weaviate-python-client). Rather than installing this package directly, you should install it as an optional extra when installing the Weaviate Python Client.

```bash
pip install weaviate-client[agents]
```
